MORLAB - Model Order Reduction Laboratory
=========================================

The MORLAB, Model Order Reduction LABoratory, toolbox is a collection of
MATLAB routines for model order reduction of dynamical systems based on
the solution of matrix equations.
The implementation is based on spectral projection methods, e.g., methods
based on the matrix sign function and the matrix disk function.


## Getting Started
------------------

### Dependencies

MATLAB R2012b and above, Octave 4.0.0 and above.

Generally, the implemented functions run fine in plain MATLAB/Octave.
However, to use the ss functionality of the toolbox, the Control
System Toolbox (MATLAB) or Control Package (Octave) is needed.

Also, some parts of the demo scripts use functions from the Control
System Toolbox (in Octave: Control Package 3.0.0 and above) and the Robust
Control Toolbox. In case of using the demo scripts without the necessary
toolboxes, the corresponding commands won't be called.


### Installation

Change to the MORLAB main folder, containing this file, and run the
`ml_addpath` function. This will add this folder together with all
subfolders to your MATLAB/Octave search path. If you do not want
to do this every time, you need to save the resulting search path.


### Using MORLAB

The toolbox includes several methods for model reduction of linear
dynamical systems in standard

      x'(t) = A*x(t) + B*u(t),
       y(t) = C*x(t) + D*u(t),

descriptor

      Ex'(t) = A*x(t) + B*u(t),
        y(t) = C*x(t) + D*u(t),

or second-order form

      M*x''(t) = -K*x(t) -  E*x'(t) + Bu*u(t),
          y(t) = Cp*x(t) + Cv*x'(t) +  D*u(t).

As a good starting point, there are demos for all implemented model
reduction methods. In the following, the implemented methods are listed,
ordered by the system classes they can be applied to:

1. Continuous-Time Standard Systems (`_ct_ss_`):
    * Bounded-Real Balanced Truncation (BRBT)
    * Balanced Stochastic Truncation (BST)
    * Balanced Truncation (BT)
    * Frequency-Limited Balanced Truncation (FLBT)
    * H-infinity Balanced Truncation (HINFBT)
    * Hankel-Norm Approximation (HNA)
    * Linear-Quadratic Gaussian Balanced Truncation (LQGBT)
    * Modal Truncation (MT)
    * Positive-Real Balanced Truncation (PRBT)
    * Time-Limited Balanced Truncation (TLBT)

2. Continuous-Time Descriptor Systems (`_ct_dss_`):
    * Bounded-Real Balanced Truncation (BRBT)
    * Balanced Stochastic Truncation (BST)
    * Balanced Truncation (BT)
    * Frequency-Limited Balanced Truncation (FLBT)
    * H-infinity Balanced Truncation (HINFBT)
    * Hankel-Norm Approximation (HNA)
    * Linear-Quadratic Gaussian Balanced Truncation (LQGBT)
    * Modal Truncation (MT)
    * Positive-Real Balanced Truncation (PRBT)
    * Time-Limited Balanced Truncation (TLBT)

3. Continuous-Time Second-Order Systems (`_ct_soss_`):
    * Balanced Truncation (BT)
    * Frequency-Limited Balanced Truncation (FLBT)
    * Time-Limited Balanced Truncation (TLBT)

The corresponding demos can be found with the naming
`morlab_demo_[system class]_[abbreviated method]`, e.g., the demo script
of the balanced truncation for standard systems is saved in
`morlab_demo_ct_ss_bt.m`. Take also a look into the next section for an
explanation of the MORLAB naming scheme.
Beside the model reduction methods, MORLAB contains several matrix equation
sovlers as well as system analysis tools.

A complete list of routines with short descriptions is generated using
`help morlab` or `help morlab-4.0`.


### Contributing to MORLAB

See [CONTRIBUTING.md](CONTRIBUTING.md) for details on how to make
contributions to the software.


## Authors
----------

See [CONTRIBUTORS.md](CONTRIBUTORS.md) for details about the authors of
the toolbox.


## License
----------

Copyright (C) 2006-2018 Peter Benner, Steffen W. R. Werner

The software is licensed under AGPLv3 or later.
See [COPYING](COPYING) for a copy of the license.


## Contact
----------

URL: http://www.mpi-magdeburg.mpg.de/projects/morlab

email: benner@mpi-magdeburg.mpg.de, werner@mpi-magdeburg.mpg.de

orcids: 0000-0003-3362-4103, 0000-0003-1667-4862


## Citation
-----------

See [CITATION.md](CITATION.md) for details about citing the software.
